==> vradi-entities-0.0.1-sources.jar: com/jurismarches/vradi/entities/GroupBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class GroupBean extends com.jurismarches.vradi.entities.QueryMakerBean implements Group, QueryMaker {

    private static final long serialVersionUID = 618480166L;

    public GroupBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String Group$name;

     public Set<String> Group$client;

     public Set<String> Group$user;

 
    public void setName(String value) {
        Object oldValue = Group$name; 
        this.Group$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return Group$name;
    }

    public Set<String> getClient() {
        return Group$client;
    }

    public void addClient(String element) {
        Group$client.add(element);
        propertyChange.firePropertyChange("client", null, Group$client);
    }
    
    public void removeClient(String element) {
        Group$client.remove(element);
        propertyChange.firePropertyChange("client", null, Group$client);
    }
    
    public void clearClient() {
        Group$client.clear();
        propertyChange.firePropertyChange("client", null, Group$client);
    }

    public Set<String> getUser() {
        return Group$user;
    }

    public void addUser(String element) {
        Group$user.add(element);
        propertyChange.firePropertyChange("user", null, Group$user);
    }
    
    public void removeUser(String element) {
        Group$user.remove(element);
        propertyChange.firePropertyChange("user", null, Group$user);
    }
    
    public void clearUser() {
        Group$user.clear();
        propertyChange.firePropertyChange("user", null, Group$user);
    }

    public Set<String> QueryMaker$queries;

     public Set<String> getQueries() {
        return QueryMaker$queries;
    }

    public void addQueries(String element) {
        QueryMaker$queries.add(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void removeQueries(String element) {
        QueryMaker$queries.remove(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void clearQueries() {
        QueryMaker$queries.clear();
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }


} //GroupBean

==> vradi-entities-0.0.5-sources.jar: com/jurismarches/vradi/entities/GroupBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class GroupBean extends com.jurismarches.vradi.entities.QueryMakerBean implements Group, QueryMaker {

    private static final long serialVersionUID = 866394379L;

    public GroupBean() {
        super();
    }

    protected transient PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String Group$name;

    public Set<String> Group$client;

    public Set<String> Group$user;


    public void setName(String value) {
        Object oldValue = Group$name; 
        this.Group$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return Group$name;
    }

    public Set<String> getClient() {
        return Group$client;
    }

    public void addClient(String element) {
        Group$client.add(element);
        propertyChange.firePropertyChange("client", null, Group$client);
    }
    
    public void removeClient(String element) {
        Group$client.remove(element);
        propertyChange.firePropertyChange("client", null, Group$client);
    }
    
    public void clearClient() {
        Group$client.clear();
        propertyChange.firePropertyChange("client", null, Group$client);
    }

    public Set<String> getUser() {
        return Group$user;
    }

    public void addUser(String element) {
        Group$user.add(element);
        propertyChange.firePropertyChange("user", null, Group$user);
    }
    
    public void removeUser(String element) {
        Group$user.remove(element);
        propertyChange.firePropertyChange("user", null, Group$user);
    }
    
    public void clearUser() {
        Group$user.clear();
        propertyChange.firePropertyChange("user", null, Group$user);
    }

    public Set<String> QueryMaker$queries;

    public Set<String> getQueries() {
        return QueryMaker$queries;
    }

    public void addQueries(String element) {
        QueryMaker$queries.add(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void removeQueries(String element) {
        QueryMaker$queries.remove(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void clearQueries() {
        QueryMaker$queries.clear();
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }


} //GroupBean
